@@ -125,7 +125,7 @@ def group_comparison(tlist):
         return (token.ttype in (T.String.Symbol, T.Name, T.Number,
                                 T.Number.Integer, T.Literal,
                                 T.Literal.Number.Integer)
-                or isinstance(token, (sql.Identifier,))
+                or isinstance(token, (sql.Identifier, sql.Parenthesis))
                 or (token.ttype is T.Keyword
                     and token.value.upper() in ['NULL', ]))
     _group_left_right(tlist, T.Operator.Comparison, None, sql.Comparison,
