@@ -262,9 +262,18 @@ def test_comparison_with_keywords():  # issue90
     assert len(p.tokens) == 1
     assert isinstance(p.tokens[0], sql.Comparison)
     assert len(p.tokens[0].tokens) == 5
-    assert p.tokens[0].tokens[0].value == 'foo'
-    assert p.tokens[0].tokens[-1].value == 'NULL'
+    assert p.tokens[0].left.value == 'foo'
+    assert p.tokens[0].right.value == 'NULL'
     # make sure it's case-insensitive
     p = sqlparse.parse('foo = null')[0]
     assert len(p.tokens) == 1
     assert isinstance(p.tokens[0], sql.Comparison)
+
+
+def test_comparison_with_parenthesis():  # issue23
+    p = sqlparse.parse('(3 + 4) = 7')[0]
+    assert len(p.tokens) == 1
+    assert isinstance(p.tokens[0], sql.Comparison)
+    comp = p.tokens[0]
+    assert isinstance(comp.left, sql.Parenthesis)
+    assert comp.right.ttype is T.Number.Integer
